@@ -1,6 +1,4 @@
 def get_md_link(title: str) -> str:
-    if title is None:
-        return ""
     title = title.lower()
     out = ""
     for c in title:
